#
# spec file for package perl-FFI-CheckLib
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-FFI-CheckLib
Version:        0.27
Release:        bp153.1.15
%define cpan_name FFI-CheckLib
Summary:        Check that a library is available for FFI
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PL/PLICEASE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test2::API) >= 1.302015
BuildRequires:  perl(Test2::Require::EnvVar) >= 0.000060
BuildRequires:  perl(Test2::Require::Module) >= 0.000060
BuildRequires:  perl(Test2::V0) >= 0.000060
%{perl_requires}

%description
This module checks whether a particular dynamic library is available for
FFI to use. It is modeled heavily on Devel::CheckLib, but will find dynamic
libraries even when development packages are not installed. It also
provides a find_lib function that will return the full path to the found
dynamic library, which can be feed directly into FFI::Platypus or another
FFI system.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc author.yml Changes example README
%license LICENSE

%changelog
* Tue May 12 2020 Tina Müller <timueller+perl@suse.de>
  updated to 0.27
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.27      2020-05-11 14:24:08 -0400
  - Added a FAQ section to the documentation (gh#22)
* Thu Jan 23 2020 <timueller+perl@suse.de>
- updated to 0.26
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.26      2020-01-22 05:54:02 -0700
  - Name check on alien option is always done, even if the Alien is already
    loaded (gh#21)
  - Remove dependency on Module::Load (gh#21)
* Tue Nov 19 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update spec file
  * Remove doc files not needed and perl-FFI-CheckLib-rpmlintrc
* Tue Nov  5 2019 Lars Vogdt <lars@linux-schulserver.de>
- added perl-FFI-CheckLib-rpmlintrc to allow building with older
  rpmlint
* Wed Jun 26 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 0.25
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.25      2019-06-25 12:27:58 -0400
  - Add support for Alien::Base with alien option (gh#18)
* Sun Apr 28 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.24
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.24      2019-04-27 09:14:34 -0400
  - Add try_linker_script option (gh#13, gh#15)
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.23
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.23      2018-11-18 00:07:49 -0500
  - Handle DLLs on Windows with "dashed" version numbers (example: foo-1-2-3.dll)
    (gh#10, gh#11, SLAFFAN++)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.22
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.22      2018-10-13 22:24:46 -0400
  - Production version identical to 0.21_01
  0.21_01   2018-10-11 22:53:43 -0400
  - Documentation fixes
  - Handle DLLs with upper-case characters in extension on MSWin32 (gh#9)
* Sun Jun 10 2018 coolo@suse.com
- updated to 0.20
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.20      2018-06-04 18:18:09 -0400
  - Add system_path function.
  0.19      2018-05-30 21:09:32 -0400
  - Administrative release to note that this dist is moving its
    repository to the Perl5-FFI org on github.com
* Thu Oct 26 2017 coolo@suse.com
- updated to 0.18
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.18      2017-10-25 10:00:47 -0400
  - Production version identical to 0.17_02
  0.17_02   2017-10-14 01:03:04 -0400
  - Fix Windows testing regression introduced in 0.17_01
  0.17_01   2017-10-13 15:58:30 -0400
  - Filter out broken and recursive symlinks
  - Better handle symlinked .so files on platforms that support that.
    Previously, we preferred the longer .so names (ie, libfoo.so.1.2.3)
    over the shorter .so names (libfoo.so) since the latter is usually a
    symlink, and the former may have useful "version" information in the
    filename.  That is a problem when a system is using symlinks to indicate
    a preference, (for example, if there are both libfoo.so.1.2.3,
    libfoo.so.1.2.4 and libfoo.so is a symlink to one of those).
    Now we still endevour to return the long .so name, but use the short
    name to see which one is preferred by the operating system, or user.
    In the absense of any symlinks to disambiguate two libraries with the
    same name, we prefer the one with a newer version number.   That is
    libfoo.so.2.3.4 would be preferred over libfoo.so.1.2.3
  - Slightly more consistent diagnostic messages.
  - Added functions: which, where, has_symbols
    None are exported by default, but may be requested.
* Wed Aug  9 2017 coolo@suse.com
- updated to 0.16
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.16      2017-08-08 10:24:49 -0400
  - Tentative support for msys
* Mon May 23 2016 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.15      2016-05-05 19:53:32 -0400
  - Add MSYS2 support
* Wed Sep 23 2015 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-FFI-CheckLib/Changes
  0.14      2015-09-09 08:25:15 -0400
  - Version identical to 0.12
    (0.12 was accidentally removed from CPAN)
  0.12      2015-08-06 16:09:32 -0400
  - Switch to MakeMaker since we are not using any features
    that require Module::Build
* Tue Feb 17 2015 coolo@suse.com
- initial package 0.11
  * created by cpanspec 1.78.08
